LastChange

Enum LastChange 

pub enum LastChange {
Show 13 variants OpMotion { op: Operator, motion: Motion, count: usize, inserted: Option<String>, }, OpTextObj { op: Operator, obj: TextObject, inner: bool, inserted: Option<String>, }, LineOp { op: Operator, count: usize, inserted: Option<String>, }, CharDel { forward: bool, count: usize, }, ReplaceChar { ch: char, count: usize, }, ToggleCase { count: usize, }, JoinLine { count: usize, }, Paste { before: bool, count: usize, cursor_after: bool, reindent: bool, }, DeleteToEol { inserted: Option<String>, }, OpenLine { above: bool, inserted: String, }, InsertAt { entry: InsertEntry, inserted: String, count: usize, }, GnOp { op: Operator, forward: bool, inserted: Option<String>, }, ReplaceMode { text: String, },
}
Information needed to replay a mutating change via ..

Variants



OpMotion

Operator over a motion.

Fields

motion: Motion
count: usize
inserted: Option<String>


OpTextObj

Operator over a text-object.

Fields

inner: bool
inserted: Option<String>


LineOp

dd, cc, yy with a count.

Fields

count: usize
inserted: Option<String>


CharDel

x, X with a count.

Fields

forward: bool
count: usize


ReplaceChar

r<ch> with a count.

Fields

ch: char
count: usize


ToggleCase

~ with a count.

Fields

count: usize


JoinLine

J with a count.

Fields

count: usize


Paste

p / P (and gp/gP, ]p/[p) with a count.

Fields

before: bool
count: usize
cursor_after: bool

gp / gP — leave the cursor just after the pasted text.

reindent: bool

]p / [p — reindent the pasted block to the current line.



DeleteToEol

D (delete to EOL).

Fields

inserted: Option<String>


OpenLine

o / O + the inserted text.

Fields

above: bool
inserted: String


InsertAt

i/I/a/A + inserted text.

Fields

inserted: String
count: usize


GnOp

dgn / cgn (and gN forms) — operate on the next search match. inserted is filled on Esc for the cgn change form so . retypes it.

Fields

forward: bool
inserted: Option<String>


ReplaceMode

R{text}<Esc> — replace (overstrike) mode. . re-overtypes text.

Fields

text: String