pub enum LastChange {
Show 13 variants
OpMotion {
op: Operator,
motion: Motion,
count: usize,
inserted: Option<String>,
},
OpTextObj {
op: Operator,
obj: TextObject,
inner: bool,
inserted: Option<String>,
},
LineOp {
op: Operator,
count: usize,
inserted: Option<String>,
},
CharDel {
forward: bool,
count: usize,
},
ReplaceChar {
ch: char,
count: usize,
},
ToggleCase {
count: usize,
},
JoinLine {
count: usize,
},
Paste {
before: bool,
count: usize,
cursor_after: bool,
reindent: bool,
},
DeleteToEol {
inserted: Option<String>,
},
OpenLine {
above: bool,
inserted: String,
},
InsertAt {
entry: InsertEntry,
inserted: String,
count: usize,
},
GnOp {
op: Operator,
forward: bool,
inserted: Option<String>,
},
ReplaceMode {
text: String,
},
}Expand description
Information needed to replay a mutating change via ..
Variants
OpMotion
Operator over a motion.
OpTextObj
Operator over a text-object.
LineOp
dd, cc, yy with a count.
CharDel
x, X with a count.
ReplaceChar
r<ch> with a count.
ToggleCase
~ with a count.
JoinLine
J with a count.
Paste
p / P (and gp/gP, ]p/[p) with a count.
Fields
DeleteToEol
D (delete to EOL).
OpenLine
o / O + the inserted text.
InsertAt
i/I/a/A + inserted text.
GnOp
dgn / cgn (and gN forms) — operate on the next search match.
inserted is filled on Esc for the cgn change form so . retypes it.
ReplaceMode
R{text}<Esc> — replace (overstrike) mode. . re-overtypes text.